==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kdeprint/kdeprintfax/faxab.h <==
/*
 *   kdeprintfax - a small fax utility
 *   Copyright (C) 2001  Michael Goffioul
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 */

#ifndef FAXAB_H
#define FAXAB_H

#include <kdialog.h>
#include <qmap.h>
#include <qstringlist.h>

class KListBox;
class AddressBook;
class QPushButton;

class FaxAB : public KDialog
{
	Q_OBJECT
public:
	FaxAB(QWidget *parent = 0, const char *name = 0);
	~FaxAB();
	bool isValid();

	static bool getEntry(QString& number, QString& name, QString& enterprise, QWidget *parent = 0);
	static bool getEntryByNumber(const QString& number, QString& name, QString& enterprise);

protected slots:
	void slotSelected(const QString&);
	void slotEditAb();
	void slotAbChanged(AddressBook*);

protected:
	void initialize();

private:
	KListBox	*m_name, *m_fax;
	QMap<QString,QStringList>	m_entries;
	QPushButton	*m_ok;
};

#endif

==> kdebase-3.5.5.tar.bz2: kdebase-3.5.5/kdeprint/kdeprintfax/faxab.h <==
/*
 *   kdeprintfax - a small fax utility
 *   Copyright (C) 2001  Michael Goffioul
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef FAXAB_H
#define FAXAB_H

#include <kdialog.h>
#include <qmap.h>
#include <qstringlist.h>
#include <kabc/phonenumber.h>

class KListView;
class AddressBook;
class QPushButton;

class FaxAB : public KDialog
{
	Q_OBJECT
public:
	FaxAB(QWidget *parent = 0, const char *name = 0);
	~FaxAB();
	bool isValid();

	static bool getEntry(QStringList& number, QStringList& name, QStringList& enterprise, QWidget *parent = 0);
	static bool getEntryByNumber(const QString& number, QString& name, QString& enterprise);

protected slots:
	void slotEditAb();
	void slotAbChanged(AddressBook*);

protected:
	void initialize();

private:
	struct FaxABEntry
	{
		QString           m_name;
		KABC::PhoneNumber m_number;
		QString           m_enterprise;
	};

	KListView*                  m_list;
	QMap<QString,FaxABEntry>    m_entries;
	QPushButton*                m_ok;
};

#endif
